package VMOMI::InvalidDasConfigArgumentEntryForInvalidArgument;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
